
From: Pavel Machek <pavel@ucw.cz>

Fix remaining bits of u32 vs.  pm_message confusion.  Should not break
anything.

Signed-off-by: Pavel Machek <pavel@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/cpu/mtrr/main.c              |    2 +-
 arch/ppc/platforms/pmac_pic.c                 |    2 +-
 arch/ppc/syslib/open_pic.c                    |    2 +-
 drivers/ide/ppc/pmac.c                        |    8 ++++----
 drivers/macintosh/mediabay.c                  |    2 +-
 drivers/media/video/bttv-driver.c             |    1 -
 drivers/media/video/msp3400.c                 |    4 ++--
 drivers/media/video/tda9887.c                 |    2 +-
 drivers/media/video/tuner-core.c              |    2 +-
 drivers/net/bnx2.c                            |   18 +++++++++---------
 drivers/net/e1000/e1000_main.c                |   14 ++++++--------
 drivers/net/irda/vlsi_ir.c                    |   11 +++--------
 drivers/net/wireless/orinoco_pci.c            |    2 --
 drivers/net/wireless/prism54/islpci_hotplug.c |    2 --
 drivers/video/s1d13xxxfb.c                    |    2 +-
 drivers/video/savage/savagefb_driver.c        |    1 -
 sound/pci/atiixp.c                            |    4 ++--
 17 files changed, 33 insertions(+), 46 deletions(-)

diff -puN arch/i386/kernel/cpu/mtrr/main.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion arch/i386/kernel/cpu/mtrr/main.c
--- devel/arch/i386/kernel/cpu/mtrr/main.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/arch/i386/kernel/cpu/mtrr/main.c	2005-07-26 17:14:16.000000000 -0700
@@ -561,7 +561,7 @@ struct mtrr_value {
 
 static struct mtrr_value * mtrr_state;
 
-static int mtrr_save(struct sys_device * sysdev, u32 state)
+static int mtrr_save(struct sys_device * sysdev, pm_message_t state)
 {
 	int i;
 	int size = num_var_ranges * sizeof(struct mtrr_value);
diff -puN arch/ppc/platforms/pmac_pic.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion arch/ppc/platforms/pmac_pic.c
--- devel/arch/ppc/platforms/pmac_pic.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/arch/ppc/platforms/pmac_pic.c	2005-07-26 17:14:16.000000000 -0700
@@ -619,7 +619,7 @@ not_found:
 	return viaint;
 }
 
-static int pmacpic_suspend(struct sys_device *sysdev, u32 state)
+static int pmacpic_suspend(struct sys_device *sysdev, pm_message_t state)
 {
 	int viaint = pmacpic_find_viaint();
 
diff -puN arch/ppc/syslib/open_pic.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion arch/ppc/syslib/open_pic.c
--- devel/arch/ppc/syslib/open_pic.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/arch/ppc/syslib/open_pic.c	2005-07-26 17:14:16.000000000 -0700
@@ -948,7 +948,7 @@ static void openpic_cached_disable_irq(u
  * we need something better to deal with that... Maybe switch to S1 for
  * cpufreq changes
  */
-int openpic_suspend(struct sys_device *sysdev, u32 state)
+int openpic_suspend(struct sys_device *sysdev, pm_message_t state)
 {
 	int	i;
 	unsigned long flags;
diff -puN drivers/ide/ppc/pmac.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/ide/ppc/pmac.c
--- devel/drivers/ide/ppc/pmac.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/ide/ppc/pmac.c	2005-07-26 17:14:16.000000000 -0700
@@ -1504,7 +1504,7 @@ pmac_ide_macio_attach(struct macio_dev *
 }
 
 static int
-pmac_ide_macio_suspend(struct macio_dev *mdev, u32 state)
+pmac_ide_macio_suspend(struct macio_dev *mdev, pm_message_t state)
 {
 	ide_hwif_t	*hwif = (ide_hwif_t *)dev_get_drvdata(&mdev->ofdev.dev);
 	int		rc = 0;
@@ -1527,7 +1527,7 @@ pmac_ide_macio_resume(struct macio_dev *
 	if (mdev->ofdev.dev.power.power_state != 0) {
 		rc = pmac_ide_do_resume(hwif);
 		if (rc == 0)
-			mdev->ofdev.dev.power.power_state = 0;
+			mdev->ofdev.dev.power.power_state = PMSG_ON;
 	}
 
 	return rc;
@@ -1608,7 +1608,7 @@ pmac_ide_pci_attach(struct pci_dev *pdev
 }
 
 static int
-pmac_ide_pci_suspend(struct pci_dev *pdev, u32 state)
+pmac_ide_pci_suspend(struct pci_dev *pdev, pm_message_t state)
 {
 	ide_hwif_t	*hwif = (ide_hwif_t *)pci_get_drvdata(pdev);
 	int		rc = 0;
@@ -1631,7 +1631,7 @@ pmac_ide_pci_resume(struct pci_dev *pdev
 	if (pdev->dev.power.power_state != 0) {
 		rc = pmac_ide_do_resume(hwif);
 		if (rc == 0)
-			pdev->dev.power.power_state = 0;
+			pdev->dev.power.power_state = PMSG_ON;
 	}
 
 	return rc;
diff -puN drivers/macintosh/mediabay.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/macintosh/mediabay.c
--- devel/drivers/macintosh/mediabay.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/macintosh/mediabay.c	2005-07-26 17:14:16.000000000 -0700
@@ -724,7 +724,7 @@ static int __pmac media_bay_resume(struc
 	struct media_bay_info	*bay = macio_get_drvdata(mdev);
 
 	if (mdev->ofdev.dev.power.power_state != 0) {
-		mdev->ofdev.dev.power.power_state = 0;
+		mdev->ofdev.dev.power.power_state = PMSG_ON;
 
 	       	/* We re-enable the bay using it's previous content
 	       	   only if it did not change. Note those bozo timings,
diff -puN drivers/media/video/bttv-driver.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/media/video/bttv-driver.c
--- devel/drivers/media/video/bttv-driver.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/media/video/bttv-driver.c	2005-07-26 17:14:16.000000000 -0700
@@ -4032,7 +4032,6 @@ static int bttv_suspend(struct pci_dev *
 	struct bttv_buffer_set idle;
 	unsigned long flags;
 
-	dprintk("bttv%d: suspend %d\n", btv->c.nr, state);
 
 	/* stop dma + irqs */
 	spin_lock_irqsave(&btv->s_lock,flags);
diff -puN drivers/media/video/msp3400.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/media/video/msp3400.c
--- devel/drivers/media/video/msp3400.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/media/video/msp3400.c	2005-07-26 17:14:16.000000000 -0700
@@ -1417,7 +1417,7 @@ static int msp_detach(struct i2c_client 
 static int msp_probe(struct i2c_adapter *adap);
 static int msp_command(struct i2c_client *client, unsigned int cmd, void *arg);
 
-static int msp_suspend(struct device * dev, u32 state, u32 level);
+static int msp_suspend(struct device * dev, pm_message_t state, u32 level);
 static int msp_resume(struct device * dev, u32 level);
 
 static void msp_wake_thread(struct i2c_client *client);
@@ -1818,7 +1818,7 @@ static int msp_command(struct i2c_client
 	return 0;
 }
 
-static int msp_suspend(struct device * dev, u32 state, u32 level)
+static int msp_suspend(struct device * dev, pm_message_t state, u32 level)
 {
 	struct i2c_client *c = container_of(dev, struct i2c_client, dev);
 
diff -puN drivers/media/video/tda9887.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/media/video/tda9887.c
--- devel/drivers/media/video/tda9887.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/media/video/tda9887.c	2005-07-26 17:14:16.000000000 -0700
@@ -760,7 +760,7 @@ tda9887_command(struct i2c_client *clien
 	return 0;
 }
 
-static int tda9887_suspend(struct device * dev, u32 state, u32 level)
+static int tda9887_suspend(struct device * dev, pm_message_t state, u32 level)
 {
 	dprintk("tda9887: suspend\n");
 	return 0;
diff -puN drivers/media/video/tuner-core.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/media/video/tuner-core.c
--- devel/drivers/media/video/tuner-core.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/media/video/tuner-core.c	2005-07-26 17:14:16.000000000 -0700
@@ -645,7 +645,7 @@ static int tuner_command(struct i2c_clie
 	return 0;
 }
 
-static int tuner_suspend(struct device *dev, u32 state, u32 level)
+static int tuner_suspend(struct device *dev, pm_message_t state, u32 level)
 {
 	struct i2c_client *c = container_of (dev, struct i2c_client, dev);
 	struct tuner *t = i2c_get_clientdata (c);
diff -puN drivers/net/bnx2.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/net/bnx2.c
--- devel/drivers/net/bnx2.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/net/bnx2.c	2005-07-26 17:14:16.000000000 -0700
@@ -1998,14 +1998,14 @@ bnx2_init_cpus(struct bnx2 *bp)
 }
 
 static int
-bnx2_set_power_state(struct bnx2 *bp, int state)
+bnx2_set_power_state(struct bnx2 *bp, pci_power_t state)
 {
 	u16 pmcsr;
 
 	pci_read_config_word(bp->pdev, bp->pm_cap + PCI_PM_CTRL, &pmcsr);
 
 	switch (state) {
-	case 0: {
+	case PCI_D0: {
 		u32 val;
 
 		pci_write_config_word(bp->pdev, bp->pm_cap + PCI_PM_CTRL,
@@ -2026,7 +2026,7 @@ bnx2_set_power_state(struct bnx2 *bp, in
 		REG_WR(bp, BNX2_RPM_CONFIG, val);
 		break;
 	}
-	case 3: {
+	case PCI_D3hot: {
 		int i;
 		u32 val, wol_msg;
 
@@ -3877,7 +3877,7 @@ bnx2_open(struct net_device *dev)
 	struct bnx2 *bp = dev->priv;
 	int rc;
 
-	bnx2_set_power_state(bp, 0);
+	bnx2_set_power_state(bp, PCI_D0);
 	bnx2_disable_int(bp);
 
 	rc = bnx2_alloc_mem(bp);
@@ -4190,7 +4190,7 @@ bnx2_close(struct net_device *dev)
 	bnx2_free_mem(bp);
 	bp->link_up = 0;
 	netif_carrier_off(bp->dev);
-	bnx2_set_power_state(bp, 3);
+	bnx2_set_power_state(bp, PCI_D3hot);
 	return 0;
 }
 
@@ -5192,7 +5192,7 @@ bnx2_init_board(struct pci_dev *pdev, st
 			       BNX2_PCICFG_MISC_CONFIG_REG_WINDOW_ENA |
 			       BNX2_PCICFG_MISC_CONFIG_TARGET_MB_WORD_SWAP);
 
-	bnx2_set_power_state(bp, 0);
+	bnx2_set_power_state(bp, PCI_D0);
 
 	bp->chip_id = REG_RD(bp, BNX2_MISC_ID);
 
@@ -5466,7 +5466,7 @@ bnx2_remove_one(struct pci_dev *pdev)
 }
 
 static int
-bnx2_suspend(struct pci_dev *pdev, u32 state)
+bnx2_suspend(struct pci_dev *pdev, pm_message_t state)
 {
 	struct net_device *dev = pci_get_drvdata(pdev);
 	struct bnx2 *bp = dev->priv;
@@ -5484,7 +5484,7 @@ bnx2_suspend(struct pci_dev *pdev, u32 s
 		reset_code = BNX2_DRV_MSG_CODE_SUSPEND_NO_WOL;
 	bnx2_reset_chip(bp, reset_code);
 	bnx2_free_skbs(bp);
-	bnx2_set_power_state(bp, state);
+	bnx2_set_power_state(bp, pci_choose_state(pdev, state));
 	return 0;
 }
 
@@ -5497,7 +5497,7 @@ bnx2_resume(struct pci_dev *pdev)
 	if (!netif_running(dev))
 		return 0;
 
-	bnx2_set_power_state(bp, 0);
+	bnx2_set_power_state(bp, PCI_D0);
 	netif_device_attach(dev);
 	bnx2_init_nic(bp);
 	bnx2_netif_start(bp);
diff -puN drivers/net/e1000/e1000_main.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/net/e1000/e1000_main.c
--- devel/drivers/net/e1000/e1000_main.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/net/e1000/e1000_main.c	2005-07-26 17:15:11.000000000 -0700
@@ -162,7 +162,7 @@ static void e1000_vlan_rx_add_vid(struct
 static void e1000_vlan_rx_kill_vid(struct net_device *netdev, uint16_t vid);
 static void e1000_restore_vlan(struct e1000_adapter *adapter);
 
-static int e1000_suspend(struct pci_dev *pdev, uint32_t state);
+static int e1000_suspend(struct pci_dev *pdev, pm_message_t state);
 #ifdef CONFIG_PM
 static int e1000_resume(struct pci_dev *pdev);
 #endif
@@ -3642,7 +3642,7 @@ e1000_set_spd_dplx(struct e1000_adapter 
 }
 
 static int
-e1000_suspend(struct pci_dev *pdev, uint32_t state)
+e1000_suspend(struct pci_dev *pdev, pm_message_t state)
 {
 	struct net_device *netdev = pci_get_drvdata(pdev);
 	struct e1000_adapter *adapter = netdev_priv(netdev);
@@ -3726,9 +3726,7 @@ e1000_suspend(struct pci_dev *pdev, uint
 	}
 
 	pci_disable_device(pdev);
-
-	state = (state > 0) ? 3 : 0;
-	pci_set_power_state(pdev, state);
+	pci_set_power_state(pdev, pci_choose_state(pdev, state));
 
 	return 0;
 }
@@ -3741,13 +3739,13 @@ e1000_resume(struct pci_dev *pdev)
 	struct e1000_adapter *adapter = netdev_priv(netdev);
 	uint32_t manc, ret_val, swsm;
 
-	pci_set_power_state(pdev, 0);
+	pci_set_power_state(pdev, PCI_D0);
 	pci_restore_state(pdev);
 	ret_val = pci_enable_device(pdev);
 	pci_set_master(pdev);
 
-	pci_enable_wake(pdev, 3, 0);
-	pci_enable_wake(pdev, 4, 0); /* 4 == D3 cold */
+	pci_enable_wake(pdev, PCI_D3hot, 0);
+	pci_enable_wake(pdev, PCI_D3cold, 0);
 
 	e1000_reset(adapter);
 	E1000_WRITE_REG(&adapter->hw, WUS, ~0);
diff -puN drivers/net/irda/vlsi_ir.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/net/irda/vlsi_ir.c
--- devel/drivers/net/irda/vlsi_ir.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/net/irda/vlsi_ir.c	2005-07-26 17:14:16.000000000 -0700
@@ -1749,11 +1749,6 @@ static int vlsi_irda_suspend(struct pci_
 	struct net_device *ndev = pci_get_drvdata(pdev);
 	vlsi_irda_dev_t *idev;
 
-	if (state < 1 || state > 3 ) {
-		IRDA_ERROR("%s - %s: invalid pm state request: %u\n",
-			   __FUNCTION__, PCIDEV_NAME(pdev), state);
-		return 0;
-	}
 	if (!ndev) {
 		IRDA_ERROR("%s - %s: no netdevice \n",
 			   __FUNCTION__, PCIDEV_NAME(pdev));
@@ -1781,7 +1776,7 @@ static int vlsi_irda_suspend(struct pci_
 			idev->new_baud = idev->baud;
 	}
 
-	pci_set_power_state(pdev,state);
+	pci_set_power_state(pdev, pci_choose_state(pdev, state));
 	pdev->current_state = state;
 	idev->resume_ok = 1;
 	up(&idev->sem);
@@ -1807,8 +1802,8 @@ static int vlsi_irda_resume(struct pci_d
 		return 0;
 	}
 	
-	pci_set_power_state(pdev, 0);
-	pdev->current_state = 0;
+	pci_set_power_state(pdev, PCI_D0);
+	pdev->current_state = PM_EVENT_ON;
 
 	if (!idev->resume_ok) {
 		/* should be obsolete now - but used to happen due to:
diff -puN drivers/net/wireless/orinoco_pci.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/net/wireless/orinoco_pci.c
--- devel/drivers/net/wireless/orinoco_pci.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/net/wireless/orinoco_pci.c	2005-07-26 17:14:16.000000000 -0700
@@ -301,8 +301,6 @@ static int orinoco_pci_suspend(struct pc
 	unsigned long flags;
 	int err;
 	
-	printk(KERN_DEBUG "%s: Orinoco-PCI entering sleep mode (state=%d)\n",
-	       dev->name, state);
 
 	err = orinoco_lock(priv, &flags);
 	if (err) {
diff -puN drivers/net/wireless/prism54/islpci_hotplug.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/net/wireless/prism54/islpci_hotplug.c
--- devel/drivers/net/wireless/prism54/islpci_hotplug.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/net/wireless/prism54/islpci_hotplug.c	2005-07-26 17:14:16.000000000 -0700
@@ -267,8 +267,6 @@ prism54_suspend(struct pci_dev *pdev, pm
 	islpci_private *priv = ndev ? netdev_priv(ndev) : NULL;
 	BUG_ON(!priv);
 
-	printk(KERN_NOTICE "%s: got suspend request (state %d)\n",
-	       ndev->name, state);
 
 	pci_save_state(pdev);
 
diff -puN drivers/video/s1d13xxxfb.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/video/s1d13xxxfb.c
--- devel/drivers/video/s1d13xxxfb.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/video/s1d13xxxfb.c	2005-07-26 17:14:16.000000000 -0700
@@ -655,7 +655,7 @@ bail:
 }
 
 #ifdef CONFIG_PM
-static int s1d13xxxfb_suspend(struct device *dev, u32 state, u32 level)
+static int s1d13xxxfb_suspend(struct device *dev, pm_message_t state, u32 level)
 {
 	struct fb_info *info = dev_get_drvdata(dev);
 	struct s1d13xxxfb_par *s1dfb = info->par;
diff -puN drivers/video/savage/savagefb_driver.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion drivers/video/savage/savagefb_driver.c
--- devel/drivers/video/savage/savagefb_driver.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/drivers/video/savage/savagefb_driver.c	2005-07-26 17:14:16.000000000 -0700
@@ -2110,7 +2110,6 @@ static int savagefb_suspend (struct pci_
 	struct savagefb_par *par = (struct savagefb_par *)info->par;
 
 	DBG("savagefb_suspend");
-	printk(KERN_DEBUG "state: %u\n", state);
 
 	acquire_console_sem();
 	fb_set_suspend(info, pci_choose_state(dev, state));
diff -puN sound/pci/atiixp.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion sound/pci/atiixp.c
--- devel/sound/pci/atiixp.c~swsusp-fix-remaining-u32-vs-pm_message_t-confusion	2005-07-26 17:14:16.000000000 -0700
+++ devel-akpm/sound/pci/atiixp.c	2005-07-26 17:14:16.000000000 -0700
@@ -1419,7 +1419,7 @@ static int snd_atiixp_suspend(snd_card_t
 	snd_atiixp_aclink_down(chip);
 	snd_atiixp_chip_stop(chip);
 
-	pci_set_power_state(chip->pci, 3);
+	pci_set_power_state(chip->pci, PCI_D3hot);
 	pci_disable_device(chip->pci);
 	return 0;
 }
@@ -1430,7 +1430,7 @@ static int snd_atiixp_resume(snd_card_t 
 	int i;
 
 	pci_enable_device(chip->pci);
-	pci_set_power_state(chip->pci, 0);
+	pci_set_power_state(chip->pci, PCI_D0);
 	pci_set_master(chip->pci);
 
 	snd_atiixp_aclink_reset(chip);
_
